@@ -146,6 +146,8 @@ nautilus_application_notify_unmount_done (NautilusApplication *application,
 		strings = g_strsplit (message, "\n", 0);
 		unplug = notify_notification_new (strings[0], strings[1],
 						  "media-removable");
+		notify_notification_set_hint (unplug,
+					      "desktop-entry", g_variant_new_string ("nautilus"));
 
 		notify_notification_show (unplug, NULL);
 		g_object_unref (unplug);
@@ -166,6 +168,8 @@ nautilus_application_notify_unmount_show (NautilusApplication *application,
 			notify_notification_new (strings[0], strings[1],
 						 "media-removable");
 
+		notify_notification_set_hint (application->priv->unmount_notify,
+					      "desktop-entry", g_variant_new_string ("nautilus"));
 		notify_notification_set_hint (application->priv->unmount_notify,
 					      "transient", g_variant_new_boolean (TRUE));
 		notify_notification_set_urgency (application->priv->unmount_notify,
@@ -558,14 +562,15 @@ open_window (NautilusApplication *application,
 	     GFile *location, GdkScreen *screen, const char *geometry)
 {
 	NautilusWindow *window;
-	gchar *uri;
 
-	uri = g_file_get_uri (location);
-	DEBUG ("Opening new window at uri %s", uri);
 	nautilus_profile_start (NULL);
-	window = nautilus_application_create_window (application,
-						     screen);
-	nautilus_window_go_to (window, location);
+	window = nautilus_application_create_window (application, screen);
+
+	if (location != NULL) {
+		nautilus_window_go_to (window, location);
+	} else {
+		nautilus_window_slot_go_home (nautilus_window_get_active_slot (window), 0);
+	}
 
 	if (geometry != NULL && !gtk_widget_get_visible (GTK_WIDGET (window))) {
 		/* never maximize windows opened from shell if a
@@ -580,8 +585,6 @@ open_window (NautilusApplication *application,
 	}
 
 	nautilus_profile_end (NULL);
-
-	g_free (uri);
 }
 
 static void
@@ -1009,6 +1012,7 @@ do_cmdline_sanity_checks (NautilusApplication *self,
 			  gboolean perform_self_check,
 			  gboolean version,
 			  gboolean kill_shell,
+			  gboolean select_uris,
 			  gchar **remaining)
 {
 	gboolean retval = FALSE;
@@ -1032,6 +1036,12 @@ do_cmdline_sanity_checks (NautilusApplication *self,
 		goto out;
 	}
 
+	if (select_uris && remaining == NULL) {
+		g_printerr ("%s\n",
+			    _("--select must be used with at least an URI."));
+		goto out;
+	}
+
 	retval = TRUE;
 
  out:
@@ -1060,6 +1070,55 @@ do_perform_self_checks (gint *exit_status)
 	*exit_status = EXIT_SUCCESS;
 }
 
+static void
+select_items_ready_cb (GObject *source,
+		       GAsyncResult *res,
+		       gpointer user_data)
+{
+	GDBusConnection *connection = G_DBUS_CONNECTION (source);
+	NautilusApplication *self = user_data;
+	GError *error = NULL;
+
+	g_dbus_connection_call_finish (connection, res, &error);
+
+	if (error != NULL) {
+		g_warning ("Unable to select specified URIs %s\n", error->message);
+		g_error_free (error);
+
+		/* open default location instead */
+		g_application_open (G_APPLICATION (self), NULL, 0, "");
+	}
+}
+
+static void
+nautilus_application_select (NautilusApplication *self,
+			     GFile **files,
+			     gint len)
+{
+	GDBusConnection *connection = g_application_get_dbus_connection (G_APPLICATION (self));
+	GVariantBuilder builder;
+	gint idx;
+	gchar *uri;
+
+	g_variant_builder_init (&builder, G_VARIANT_TYPE ("as"));
+	for (idx = 0; idx < len; idx++) {
+		uri = g_file_get_uri (files[idx]);
+		g_variant_builder_add (&builder, "s", uri);
+		g_free (uri);
+	}
+
+	g_dbus_connection_call (connection,
+				NAUTILUS_FDO_DBUS_NAME,
+				NAUTILUS_FDO_DBUS_PATH,
+				NAUTILUS_FDO_DBUS_IFACE,
+				"ShowItems",
+				g_variant_new ("(ass)", &builder, ""), NULL,
+				G_DBUS_CALL_FLAGS_NONE, G_MAXINT, NULL,
+				select_items_ready_cb, self);
+
+	g_variant_builder_clear (&builder);
+}
+
 static gboolean
 nautilus_application_local_command_line (GApplication *application,
 					 gchar ***arguments,
@@ -1070,6 +1129,7 @@ nautilus_application_local_command_line (GApplication *application,
 	gboolean browser = FALSE;
 	gboolean kill_shell = FALSE;
 	gboolean no_default_window = FALSE;
+	gboolean select_uris = FALSE;
 	gchar **remaining = NULL;
 	NautilusApplication *self = NAUTILUS_APPLICATION (application);
 
@@ -1091,6 +1151,8 @@ nautilus_application_local_command_line (GApplication *application,
 		  N_("Do not manage the desktop (ignore the preference set in the preferences dialog)."), NULL },
 		{ "quit", 'q', 0, G_OPTION_ARG_NONE, &kill_shell, 
 		  N_("Quit Nautilus."), NULL },
+		{ "select", 's', 0, G_OPTION_ARG_NONE, &select_uris,
+		  N_("Select specified URI in parent folder."), NULL },
 		{ G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &remaining, NULL,  N_("[URI...]") },
 
 		{ NULL }
@@ -1127,7 +1189,7 @@ nautilus_application_local_command_line (GApplication *application,
 	}
 
 	if (!do_cmdline_sanity_checks (self, perform_self_check,
-				       version, kill_shell, remaining)) {
+				       version, kill_shell, select_uris, remaining)) {
 		*exit_status = EXIT_FAILURE;
 		goto out;
 	}
@@ -1185,7 +1247,7 @@ nautilus_application_local_command_line (GApplication *application,
 		g_strfreev (remaining);
 	}
 
-	if (files == NULL && !no_default_window) {
+	if (files == NULL && !no_default_window && !select_uris) {
 		files = g_malloc0 (2 * sizeof (GFile *));
 		len = 1;
 
@@ -1193,8 +1255,14 @@ nautilus_application_local_command_line (GApplication *application,
 		files[1] = NULL;
 	}
 
-	/* Invoke "Open" to create new windows */
-	if (len > 0) {
+	if (len == 0) {
+		goto out;
+	}
+
+	if (select_uris) {
+		nautilus_application_select (self, files, len);
+	} else {
+		/* Invoke "Open" to create new windows */
 		g_application_open (application, files, len, "");
 	}
 
