@@ -62,7 +62,6 @@
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-profile.h>
 #include <libnautilus-private/nautilus-clipboard.h>
-#include <libnautilus-private/nautilus-search-directory.h>
 #include <libnautilus-private/nautilus-signaller.h>
 
 #define DEBUG_FLAG NAUTILUS_DEBUG_WINDOW
@@ -206,10 +205,13 @@ void
 nautilus_window_grab_focus (NautilusWindow *window)
 {
 	NautilusWindowSlot *slot;
+	NautilusView *view;
 
 	slot = nautilus_window_get_active_slot (window);
-	if (slot) {
-		nautilus_view_grab_focus (nautilus_window_slot_get_view (slot));
+	view = nautilus_window_slot_get_view (slot);
+
+	if (view) {
+		nautilus_view_grab_focus (view);
 	}
 }
 
@@ -270,37 +272,6 @@ notebook_switch_page_cb (GtkNotebook    *notebook,
 	return FALSE;
 }
 
-void
-nautilus_window_set_search_visible (NautilusWindow *window,
-				    gboolean visible)
-{
-	NautilusWindowSlot *slot;
-
-	slot = window->details->active_slot;
-
-	if (visible) {
-		remember_focus_widget (window);
-		nautilus_window_slot_set_query_editor_visible (slot, TRUE);
-	} else {
-		GFile *location = NULL;
-
-		restore_focus_widget (window);
-
-		/* Use the location bar as the return location */
-		location = nautilus_window_slot_get_query_editor_location (slot);
-
-		/* Last try: use the home directory as the return location */
-		if (location == NULL) {
-			location = g_file_new_for_path (g_get_home_dir ());
-		}
-
-		nautilus_window_go_to (window, location);
-		g_object_unref (location);
-
-		nautilus_window_slot_set_query_editor_visible (slot, FALSE);
-	}
-}
-
 static void
 close_slot (NautilusWindow     *window,
 	    NautilusWindowSlot *slot,
@@ -1204,6 +1175,12 @@ nautilus_window_constructed (GObject *self)
 	slot = nautilus_window_open_slot (window, 0);
 	nautilus_window_set_active_slot (window, slot);
 
+	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR)) {
+		nautilus_window_show_sidebar (window);
+	} else {
+		nautilus_window_hide_sidebar (window);
+	}
+
 	application = NAUTILUS_APPLICATION (g_application_get_default ());
 	window->details->bookmarks_id =
 		g_signal_connect_swapped (nautilus_application_get_bookmarks (application), "changed",
@@ -1403,7 +1380,7 @@ nautilus_window_report_location_change (NautilusWindow *window)
 	uri = nautilus_window_slot_get_current_uri (slot);
 
 	if (uri != NULL) {
-		g_signal_emit_by_name (window, "loading-uri", uri);
+		g_signal_emit (window, signals[LOADING_URI], 0, uri);
 		g_free (uri);
 	}
 }
@@ -1740,12 +1717,6 @@ nautilus_window_show (GtkWidget *widget)
 
 	window = NAUTILUS_WINDOW (widget);
 
-	if (g_settings_get_boolean (nautilus_window_state, NAUTILUS_WINDOW_STATE_START_WITH_SIDEBAR)) {
-		nautilus_window_show_sidebar (window);
-	} else {
-		nautilus_window_hide_sidebar (window);
-	}
-
 	GTK_WIDGET_CLASS (nautilus_window_parent_class)->show (widget);	
 
 	gtk_ui_manager_ensure_update (window->details->ui_manager);
